Access the 'Cumulocity' API and retrieve data on devices, measurements, and events.
get_devices returns available devices for a tenant.
get_measurements returns measurements for a device.
get_events returns events for a device.
The package expects a local .Renviron file with credentials defined as follows:
CUMULOCITY_base_url = "[tenant url]" CUMULOCITY_usr = "[username]" CUMULOCITY_pwd = "[password]" CUMULOCITY_device_id = "[an example device id]"
The tenant url should be of the form "https://tenant_name.cumulocity.com".
CUMULOCITY_device_id is not required by any of the main functions.
.Renviron can be edited with usethis::edit_r_environ().
Time should be in the following format: "YYYY-MM-DDTHH:MM:SSZ"
Useful links: